==> haskell-yesod-form-1.4.11-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.11
id: yesod-form-1.4.11-DG2zyYM4gQeKZxrkqPQQT
key: yesod-form-1.4.11-DG2zyYM4gQeKZxrkqPQQT
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
    Yesod.Form.I18n.Spanish
abi: ea5ae7bd33fb2868d747da49b693f1c2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.11
data-dir: /usr/share/i386-linux-ghc-8.0.1/yesod-form-1.4.11
hs-libraries: HSyesod-form-1.4.11-DG2zyYM4gQeKZxrkqPQQT
depends:
    aeson-1.0.2.1-12Tr6G2d7dgKxXx9Jv4gDD
    attoparsec-0.13.1.0-A4pUaeqQWkyDZOYwXw4PvN base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    email-validate-2.2.0-88btLlOLgqGIuzEPmD2uOw
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    persistent-2.6.1-G1ySI0gYR5jBJqWNDOlavM
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    shakespeare-2.0.12.1-5WblY5eqldADvWE6dLRZAB
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    wai-3.2.1.1-1k6hSu2jHMHEfd9vQlBLrn
    xss-sanitize-0.3.5.7-52sK2IstXftHMu6Gfxxz0d
    yesod-core-1.4.32-EEZC8CWfpQn6wL3uaFRoyv
    yesod-persistent-1.4.2-2wQe4jKKRJ62Zw9wE2cn8I
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.4.11-30-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.11
id: yesod-form-1.4.11-IGvW7xpH4XvGPNpSRICKgE
key: yesod-form-1.4.11-IGvW7xpH4XvGPNpSRICKgE
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
    Yesod.Form.I18n.Spanish
abi: e368f0993f9f09e66526a7b2f6684df0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.11
data-dir: /usr/share/i386-linux-ghc-8.0.1/yesod-form-1.4.11
hs-libraries: HSyesod-form-1.4.11-IGvW7xpH4XvGPNpSRICKgE
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    email-validate-2.2.0-J6PlAOHUAgYCvv54qfKjUz
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    persistent-2.6.1-Bj2UKzWMyMVJmynx4AHWe9
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    shakespeare-2.0.13-1ykqS7jOpmsDuiCH9lVHMQ template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    transformers-0.5.2.0 wai-3.2.1.1-HegeDw2KVvNKTqaIBuqg9O
    xss-sanitize-0.3.5.7-Enknq3BFf90DHjL4gDzDUx
    yesod-core-1.4.33-648yjErMooJ8KcJ5rVV3Lq
    yesod-persistent-1.4.2-2kNklwjgACb91OWrvoskCJ
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
